@@ -4,30 +4,23 @@ from itertools import chain
 
 iterchain = chain.from_iterable
 
-import abc
+import clu.abstract
 import collections
 import collections.abc
 
 from clu.constants.consts import NoDefault
-from clu.exporting import Slotted, Exporter
+from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # DICT VIEWS: OrderedMappingView and friends
 
-class ClassWrapRepr(abc.ABC):
-    
-    def __repr__(self):
-        clsname = type(self).__name__
-        mapping = repr(self._mapping)
-        return f"{clsname}<{mapping}>"
-
 @export
 class OrderedMappingView(collections.abc.MappingView,
                          collections.abc.Sequence,
                          collections.abc.Reversible,
-                         ClassWrapRepr):
+                         clu.abstract.MappingViewRepr):
     
     """ A mapping view class implementing “collections.abc.Sequence”
         and “collections.abc.Reversible”
@@ -38,14 +31,12 @@ class OrderedMappingView(collections.abc.MappingView,
     
     def __getitem__(self, idx):
         return tuple(self)[idx]
-    
-    __repr__ = ClassWrapRepr.__repr__
 
 @export
 class OrderedItemsView(collections.abc.ItemsView,
                        collections.abc.Sequence,
                        collections.abc.Reversible,
-                       ClassWrapRepr):
+                       clu.abstract.MappingViewRepr):
     
     """ An items-view class implementing “collections.abc.Sequence”
         and “collections.abc.Reversible”
@@ -57,14 +48,12 @@ class OrderedItemsView(collections.abc.ItemsView,
     
     def __getitem__(self, idx):
         return tuple(self)[idx]
-    
-    __repr__ = ClassWrapRepr.__repr__
 
 @export
 class OrderedKeysView(collections.abc.KeysView,
                       collections.abc.Sequence,
                       collections.abc.Reversible,
-                      ClassWrapRepr):
+                      clu.abstract.MappingViewRepr):
     
     """ A keys-view class implementing “collections.abc.Sequence”
         and “collections.abc.Reversible”
@@ -75,14 +64,12 @@ class OrderedKeysView(collections.abc.KeysView,
     
     def __getitem__(self, idx):
         return tuple(self)[idx]
-    
-    __repr__ = ClassWrapRepr.__repr__
 
 @export
 class OrderedValuesView(collections.abc.ValuesView,
                         collections.abc.Sequence,
                         collections.abc.Reversible,
-                        ClassWrapRepr):
+                        clu.abstract.MappingViewRepr):
     
     """ A values-view class implementing “collections.abc.Sequence”
         and “collections.abc.Reversible”
@@ -94,13 +81,14 @@ class OrderedValuesView(collections.abc.ValuesView,
     
     def __getitem__(self, idx):
         return tuple(self)[idx]
-    
-    __repr__ = ClassWrapRepr.__repr__
 
 # CHAINMAP: a reimplementation
 
 @export
-class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
+class ChainMap(collections.abc.MutableMapping,
+               clu.abstract.Cloneable,
+               clu.abstract.ReprWrapper,
+               metaclass=clu.abstract.Slotted):
     
     __slots__ = ('maps', '__weakref__')
     
@@ -118,16 +106,19 @@ class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
             
             The signature of “clu.dicts.ChainMap.__init__(…)” is functionally the
             same as as “clu.dicts.merge(…)” (q.v. definition sub.)
+            
+            Instances of either “clu.dicts.ChainMap” or its spiritual predecessor,
+            “collections.ChainMap”, will have their constituent dicts extracted
+            and individually appended to the new ChainMaps’ internal list.
         """
         extras = [dict(**overrides)]
         maps = [] # type: list
         for d in dicts:
-            if isinstance(d, type(self)):
-                # maps.extend(map for map in d.maps if bool(map))
+            if isinstance(d, (type(self), collections.ChainMap)):
                 for map in d.maps:
                     if bool(map):
                         if map not in maps:
-                            maps.append(d)
+                            maps.append(map)
             else:
                 if d not in maps:
                     maps.append(d)
@@ -144,7 +135,6 @@ class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
         return try_items(key, *self.maps, default=None) or self.__missing__(key)
     
     def __len__(self):
-        # return len(set().union(*self.maps))
         return len(frozenset(iterchain(self.maps)))
     
     def __bool__(self):
@@ -175,7 +165,7 @@ class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
         """
         # Equivalent to collections.ChainMap.new_child(…)
         cls = type(self)
-        if isinstance(map, cls):
+        if isinstance(map, (cls, collections.ChainMap)):
             return cls(*(m for m in map.maps if bool(m)), *self.maps)
         return cls(map or {}, *self.maps)
     
@@ -203,7 +193,7 @@ class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
         self.maps[0].clear()
         return self
     
-    def mapcontains(self, itx, default=NoDefault):
+    def mapcontaining(self, itx, default=NoDefault):
         from clu.predicates import finditem
         if default is NoDefault:
             return finditem(itx, *self.maps) or self.__missing__(itx)
@@ -224,18 +214,6 @@ class ChainMap(collections.abc.MutableMapping, metaclass=Slotted):
     def inner_repr(self):
         from pprint import pformat
         return pformat(self.maps)
-    
-    def __repr__(self):
-        from clu.fs.misc import typename_hexid
-        cnm, hxa = typename_hexid(self)
-        rpr = self.inner_repr()
-        return f"{cnm}({rpr}) @ {hxa}"
-    
-    def __copy__(self):
-        return self.clone()
-    
-    def __deepcopy__(self, memo):
-        return self.clone(deep=True, memo=memo)
 
 # DICT FUNCTIONS: dictionary-merging
 
@@ -299,7 +277,7 @@ def test():
     from clu.constants.data import XDGS
     from clu.fs.filesystem import Directory
     from clu.predicates import try_items
-    from clu.testing.utils import pout
+    from clu.testing.utils import pout, inline
     import os
     
     dirname = Directory(TEST_PATH)
@@ -319,6 +297,7 @@ def test():
                 del os.environ[key]
         return os.environ
     
+    @inline
     def test_one():
         try:
             env = environment()
@@ -365,8 +344,9 @@ def test():
             
         finally:
             os.environ = stash # type: ignore
-        
-    test_one()
+    
+    # Run all inline tests:
+    inline.test(vars())
 
 if __name__ == '__main__':
     test()
\ No newline at end of file
