@@ -25,16 +25,17 @@ except ImportError:
     import importlib_metadata as _metadata
     importlib.metadata = _metadata
 
-from clu.constants.consts import BUILTINS, PROJECT_NAME, QUALIFIER, NoDefault
+from clu.constants import consts
 from clu.extending import Extensible
 from clu.naming import nameof, dotpath_split, dotpath_join
-from clu.predicates import attr, attr_search, mro, typeof, newtype
+from clu.predicates import attr, attr_search, mro
 from clu.typespace import Namespace, types
 from clu.typology import ismodule, ismapping, isstring, subclasscheck
 from clu.exporting import Registry as ExporterRegistry
-from clu.exporting import itermodule
 from clu.exporting import ExporterBase, Exporter
 
+NoDefault = consts.NoDefault
+
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
@@ -81,10 +82,12 @@ class MetaRegistry(Extensible):
         """ Unregister a previously-registered per-appname class from the registry """
         if Registry.has_appname(appname):
             if qualified_name in Registry.monomers[appname]:
-                importlib.invalidate_caches()
                 cls = Registry.monomers[appname].pop(qualified_name)
+                if qualified_name in sys.modules:
+                    del sys.modules[qualified_name]
                 if hasattr(cls, 'exporter'):
                     cls.exporter.unregister(qualified_name)
+                importlib.invalidate_caches()
                 return bool(cls)
         return False
 
@@ -118,15 +121,19 @@ class Registry(abc.ABC, metaclass=MetaRegistry):
             then register it – store a weakref to it in the per-appname
             dictionary, indexed by the qualified name.
         """
+        # Call up:
+        super(Registry, cls).__init_subclass__(**kwargs)
+        
         # We were called with a class for which the values
         # of appname, appspace, and __name__ have been assigned:
         if cls.appname and cls.appspace and nameof(cls):
-            # Register if the names are good:
+            # Register this subclass if the names are good:
             if cls.qualname not in Registry.monomers[cls.appname]:
                 Registry.monomers[cls.appname][cls.qualname] = cls
-        
-        # Call up:
-        super(Registry, cls).__init_subclass__(**kwargs)
+            # Register the root class for this subclass,
+            # also name-wellness permitting:
+            # if cls.prefix not in Registry.monomers[cls.appname]:
+            #     Registry.monomers[cls.appname][cls.qualname] = ???
 
 @export
 class ModuleSpec(importlib.machinery.ModuleSpec):
@@ -208,7 +215,7 @@ class FinderBase(clu.abstract.AppName, importlib.abc.MetaPathFinder):
         # with classes like 'str' …?!
         if fullname in cls.cache:
             return cls.cache[fullname]
-        if cls.appname == fullname.split(QUALIFIER).pop(0):
+        if cls.appname == fullname.split(consts.QUALIFIER).pop(0):
             out = cls.cache[fullname] = ModuleSpec(fullname, cls.loader)
             return out
         return None
@@ -404,7 +411,7 @@ class MetaModule(MetaRegistry):
         
         # If an appname is defined, try to install
         # an instance of the appropriate Exporter:
-        if cls.appname is not None and name != 'Module':
+        if cls.appname is not None and not name.endswith('Module'):
             if ExporterRegistry.has_appname(cls.appname):
                 ExporterClass = ExporterRegistry[cls.appname]
                 cls.exporter = ExporterClass(dotpath=cls.qualname)
@@ -555,7 +562,7 @@ def initialize_types(appname, appspace='app'):
     
     return Module, Finder, Loader
 
-Module, Finder, Loader = initialize_types(PROJECT_NAME)
+Module, Finder, Loader = initialize_types(consts.PROJECT_NAME)
 
 @export
 class ChainModuleMap(clu.dicts.ChainMap):
@@ -563,8 +570,8 @@ class ChainModuleMap(clu.dicts.ChainMap):
     """ Custom “clu.dicts.ChainMap” subclass, tailored for module dicts """
     
     def __iter__(self):
-        source = super().__iter__()
-        yield from filter(lambda item: item not in BUILTINS, source)
+        yield from filter(lambda item: item not in consts.BUILTINS,
+                          super().__iter__())
     
     def __missing__(self, key):
         if key in self:
@@ -580,19 +587,18 @@ def add_targets(instance, *targets):
     """ Out-of-line, use-twice-and-destroy function for processing targets """
     if getattr(instance, 'target_dicts', None) is None:
         instance.target_dicts = []
-    cls = type(instance)
+    if getattr(instance, 'target_lists', None) is None:
+        instance.target_lists = []
     for target in targets:
         if target is None:
             continue
         if ismodule(target):
             instance.target_dicts.append(target.__dict__)
-            if hasattr(target, 'exporter'):
-                cls.exporter.update(target.exporter)
-            else:
-                cls.exporter.update(itermodule(target))
+            instance.target_lists.append(dir(target))
             continue
         if ismapping(target):
             instance.target_dicts.append(target)
+            instance.target_lists.append(list(target.keys()))
             continue
 
 @export
@@ -616,8 +622,15 @@ class ProxyModule(Module):
             along through the “ChainMap” instances’ internal stack of
             mappings.
         """
+        # in case of __dir__(…) access before execution:
+        if not hasattr(self, '__proxies__'):
+            self.__proxies__ = {}
+        if not hasattr(self, '__filters__'):
+            self.__filters__ = []
+        
         # Establish a base list of target dicts, and call up:
         self.target_dicts = []
+        self.target_lists = []
         super(ProxyModule, self).__init__(name, doc=doc)
         
         # Get a reference to the module class:
@@ -631,17 +644,25 @@ class ProxyModule(Module):
         # list attribute, if it exists:
         if hasattr(cls, 'targets'):
             add_targets(self, *cls.targets)
-            del cls.targets
+            delattr(cls, 'targets')
     
     def __execute__(self):
         # Create the internal “clu.dicts.ChainMap” subclass instance:
         self.__proxies__ = ChainModuleMap(*self.target_dicts)
+        self.__filters__ = tuple(iterchain(self.target_lists))
+        
+        # Further unclutter the module namespace:
+        delattr(self, 'target_dicts')
+        delattr(self, 'target_lists')
         
         # Call up:
         super().__execute__()
-        
-        # Further unclutter the module namespace:
-        del self.target_dicts
+    
+    def __dir__(self):
+        cls = type(self)
+        names = chain(self.__filters__,
+                       cls.__dict__.keys())
+        return sorted(frozenset(names) - DO_NOT_INCLUDE)
     
     def __getattr__(self, key):
         # N.B. AttributeError typenames (herein “ProxyModule”) must be
@@ -652,54 +673,13 @@ class ProxyModule(Module):
         try:
             if not self.__dict__.get('_executed', False):
                 raise KeyError(key)
-            elif key in BUILTINS:
+            elif key in consts.BUILTINS:
                 raise KeyError(key)
             return self.__proxies__[key]
         except KeyError:
             typename = type(self).__name__
             raise AttributeError(f"‘{typename}’ proxy module has no attribute ‘{key}’")
 
-@export
-class SubModule(object):
-    
-    """ A context manager that creates a temporary
-        class-module subclass on enter, and unregisters
-        the temporary subclass on exit. Handy for testing.
-    """
-    
-    __slots__ = ('ModuleClass', 'ModuleSubclass', 'name', 'kwargs')
-    
-    def __init__(self, name='ModuleSubclass',
-                       ModuleClass=NoDefault,
-                     **kwargs):
-        """ Initializes a SubModule context manager with a given
-            module class (defaults to “clu.importing.Module”).
-        """
-        if not name:
-            raise TypeError("a name is required")
-        if ModuleClass in (None, NoDefault):
-            ModuleClass = Module
-        if not subclasscheck(ModuleClass, ModuleBase):
-            cls = typeof(ModuleClass)
-            raise TypeError(f"Module class must derive from “clu.importing.ModuleBase” "
-                            f"(class {cls.__qualname__} does not)")
-        self.ModuleClass = typeof(ModuleClass)
-        self.name = name
-        self.kwargs = kwargs
-    
-    def __enter__(self):
-        """ Create and return the temporary class-module subclass """
-        self.ModuleSubclass = newtype(self.name,
-                                      self.ModuleClass,
-                                    **self.kwargs)
-        return self.ModuleSubclass
-    
-    def __exit__(self, exc_type=None, exc_val=None, exc_tb=None):
-        """ Unregister the temporary class-module subclass """
-        Registry.unregister(self.ModuleSubclass.appname,
-                            self.ModuleSubclass.qualname)
-        return exc_type is None
-
 export(Module, name='Module')
 export(Finder, name='Finder')
 export(Loader, name='Loader')
@@ -715,12 +695,12 @@ def test():
     @inline
     def test_one():
         
-        m = Module(PROJECT_NAME)
+        m = Module(consts.PROJECT_NAME)
         assert m
-        assert m.appname == PROJECT_NAME
+        assert m.appname == consts.PROJECT_NAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == PROJECT_NAME
+        assert nameof(m) == consts.PROJECT_NAME
         print(nameof(m))
         print(m.__name__)
     
@@ -748,14 +728,10 @@ def test():
     def test_three():
         assert pout
         
-        # registry = dict(Registry.monomers)
-        # pout.v(registry)
-        # pout.v(Module.__dict__)
-        
         pout.v(all_registered_appnames())
         pout.v(all_registered_modules())
         
-        m = Module(PROJECT_NAME)
+        m = Module(consts.PROJECT_NAME)
         
         assert len(Registry.monomers) > 0
         try:
@@ -767,10 +743,10 @@ def test():
         
         pout.v(m.__dict__)
         
-        assert m.appname == PROJECT_NAME
+        assert m.appname == consts.PROJECT_NAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == PROJECT_NAME
+        assert nameof(m) == consts.PROJECT_NAME
         
         pout.v(mro(m))
     
@@ -784,11 +760,9 @@ def test():
             pass
         
         spec = finder.find_spec('clu.app.FindMe', [])
-        # pout.v(spec.__dict__)
         assert spec.name == 'clu.app.FindMe'
         
         module = finder.loader.create_module(spec)
-        # pout.v(module)
         assert type(module) is FindMe
         
         pout.v(mro(finder))
@@ -817,11 +791,6 @@ def test():
         assert type(derived) is Derived
         assert derived.yo == 'dogg'
         
-        # print(derived.__spec__)
-        # pout.v(dict(derived.__dict__))
-        # pout.v(derived.__spec__)
-        # pout.v(derived.__dict__.keys())
-        
         for attname in dir(derived):
             assert hasattr(derived, attname)
         
@@ -833,44 +802,6 @@ def test():
     @inline
     def test_five():
         
-        before = all_registered_modules()
-        
-        with SubModule('derived_module0', __module__=__name__) as DerivedModule:
-            from clu.app import derived_module0 as derived
-            
-            assert type(derived) is DerivedModule
-            assert type(derived.exporter).__name__ == 'Exporter'
-            assert len(all_registered_modules()) == len(before) + 1
-        
-        after = all_registered_modules()
-        assert before == after
-    
-    @inline
-    def test_six():
-        
-        before = all_registered_modules()
-        
-        with SubModule('derived_module1', __module__=__name__) as DerivedModule:
-            derived = importlib.import_module('clu.app.derived_module1')
-            
-            assert type(derived) is DerivedModule
-            assert derived.__class__ is DerivedModule
-            assert isinstance(derived, DerivedModule)
-            assert subclasscheck(type(derived), DerivedModule)
-            print(type(DerivedModule))
-            print(DerivedModule)
-            print(type(derived))
-            pprint(mro(derived))
-            assert type(derived.exporter).__name__ == 'Exporter'
-            assert len(all_registered_modules()) == len(before) + 1
-        
-        after = all_registered_modules()
-        assert before == after
-    
-    @inline
-    def test_seven():
-        from clu.constants import consts
-        
         overrides = dict(PROJECT_NAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
@@ -889,7 +820,6 @@ def test():
         assert not hasattr(overridden, 'targets')
         assert not hasattr(overridden, 'target_dicts')
         
-        # pout.v(overridden.exporter)
         # pout.v(overridden)
         pprint(overridden.__proxies__)
         
@@ -897,14 +827,7 @@ def test():
         return dir(overridden)
     
     # Run all tests:
-    test_one()
-    test_two()
-    test_three()
-    three_and_a_half()
-    test_four()
-    test_five()
-    test_six()
-    test_seven()
+    inline.test(vars())
 
 if __name__ == '__main__':
     test()
\ No newline at end of file
