@@ -51,9 +51,9 @@ from clu.exporting import (itermodule, moduleids, itermoduleids,
                            search_for_name, search_for_module,
                            search_modules,
                            determine_name,
-                           sysmods,
-                           Exporter, ExporterBase, Registry,
-                           path_to_dotpath)
+                           path_to_dotpath,
+                           Exporter, ExporterBase,
+                           Registry)
 
 from clu.extending import (Extensible,
                            pairtype, ΩΩ, pairmro, ω, pair, Ω,
@@ -68,7 +68,7 @@ from clu.importing import (Module, Finder, Loader,
                            ModuleBase, FinderBase, LoaderBase,
                            Package, ModuleSpec,
                            Registry as ClassModuleRegistry,
-                           ArgumentSink, SubModule)
+                           ArgumentSink)
 
 from clu.sanitizer import sanitize, sanitizers, utf8_encode, utf8_decode
 from clu.version import version_info
@@ -146,10 +146,11 @@ from clu.naming import (determine_module, nameof, moduleof,
 
 from clu.abstract import Cloneable, ReprWrapper
 
-from clu.config.abc import (NAMESPACE_SEP, FlatOrderedSet,
-                                           functional_and,
-                                           functional_set, NamespacedMutableMapping)
-from clu.config.base import Flat, Nested
+# from clu.config.base import Flat, Nested
+from clu.config.abc import FlatOrderedSet, functional_and, functional_set
+from clu.config.defg import (NAMESPACE_SEP, FrozenKeyMap, KeyMap, FrozenFlat, Flat,
+                                                                  FrozenNested, Nested)
+
 from clu.config.env import Env
 from clu.config.filebase import FileName, FileBase
 from clu.config.fieldtypes import ValidationError
@@ -304,7 +305,6 @@ __all__ = ('Image',
            'search_for_name', 'search_for_module',
            'search_modules',
            'determine_name',
-           'sysmods',
            'Exporter', 'ExporterBase', 'Registry',
            'path_to_dotpath',
            'Extensible',
@@ -319,7 +319,7 @@ __all__ = ('Image',
            'ModuleBase', 'FinderBase', 'LoaderBase',
            'Package', 'ModuleSpec',
            'ClassModuleRegistry',
-           'ArgumentSink', 'SubModule',
+           'ArgumentSink',
            'negate', 'reverse',
            'ismetaclass', 'isclass', 'isclasstype',
            'metaclass', 'typeof',
@@ -386,7 +386,9 @@ __all__ = ('Image',
            'qualified_import', 'qualified_name_tuple', 'qualified_name',
            'dotpath_to_prefix', 'path_to_prefix',
            'split_abbreviations',
-           'NAMESPACE_SEP', 'Cloneable', 'ReprWrapper', 'FlatOrderedSet', 'NamespacedMutableMapping',
+           'NAMESPACE_SEP', 'Cloneable', 'ReprWrapper', 'FlatOrderedSet',
+           'FrozenKeyMap', 'KeyMap',
+           'FrozenFlat', 'FrozenNested',
            'Flat', 'Nested',
            'Env', 'FileName', 'FileBase',
            'ValidationError', 'hoist',
